==> haskell-string-qq-0.0.6-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-qq
version:              0.0.6
visibility:           public
id:                   string-qq-0.0.6-7StvPWldqfEARUCx6oDiXg
key:                  string-qq-0.0.6-7StvPWldqfEARUCx6oDiXg
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            unstable
synopsis:
    QuasiQuoter for non-interpolated strings, texts and bytestrings.

description:
    QuasiQuoter for non-interpolated strings, texts and bytestrings, useful for writing multi-line IsString literals.

category:             Data
abi:                  dbe0e6637811e39c75146ed7d8b01321
exposed:              True
exposed-modules:      Data.String.QQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/string-qq-0.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/string-qq-0.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/string-qq-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-qq
hs-libraries:         HSstring-qq-0.0.6-7StvPWldqfEARUCx6oDiXg
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-string-qq/html/string-qq.haddock
haddock-html:         /usr/share/doc/haskell-string-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-qq-0.0.6-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-qq
version:              0.0.6
visibility:           public
id:                   string-qq-0.0.6-D9hZu7Gm4qc2ipHGgxgO8N
key:                  string-qq-0.0.6-D9hZu7Gm4qc2ipHGgxgO8N
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            unstable
synopsis:
    QuasiQuoter for non-interpolated strings, texts and bytestrings.

description:
    QuasiQuoter for non-interpolated strings, texts and bytestrings, useful for writing multi-line IsString literals.

category:             Data
abi:                  7b4f455d753c30a37ee7349b7ed82994
exposed:              True
exposed-modules:      Data.String.QQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/string-qq-0.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/string-qq-0.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/string-qq-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-qq
hs-libraries:         HSstring-qq-0.0.6-D9hZu7Gm4qc2ipHGgxgO8N
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-string-qq/html/string-qq.haddock
haddock-html:         /usr/share/doc/haskell-string-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
